AutoSmsVerification class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
appSignature(
) → Future< String?> - Retrieves the app signature, only for Android platform
-
startListeningSms(
) → Future< String?> - Starts listening for SMS messages, only for Android platform
-
stopListening(
) → Future< String?> - Stops listening for SMS messages, only for Android platform